gf2x: Fast arithmetic in GF(2)[x] and searching for irreducible/primitive trinomials
====================================================================================

Description
-----------

gf2x is a C/C++ software package containing routines for fast arithmetic
in GF(2)[x] (multiplication, squaring, GCD) and searching for
irreducible/primitive trinomials.

Website: https://gitlab.inria.fr/gf2x/gf2x

License
-------

-  GNU GPLv2+.


Upstream Contact
----------------

-  Richard Brent
-  Pierrick Gaudry
-  Emmanuel Thomé
-  Paul Zimmermann
